/****************************************************************************
** Meta object code from reading C++ file 'fcitx4inputmethodproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../fcitx4inputmethodproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fcitx4inputmethodproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5fcitx22Fcitx4InputMethodProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto fcitx::Fcitx4InputMethodProxy::qt_create_metaobjectdata<qt_meta_tag_ZN5fcitx22Fcitx4InputMethodProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "fcitx::Fcitx4InputMethodProxy",
        "CreateICv3",
        "QDBusPendingReply<int,bool,uint,uint,uint,uint>",
        "",
        "appname",
        "pid",
        "QDBusReply<int>",
        "bool&",
        "enable",
        "uint&",
        "keyval1",
        "state1",
        "keyval2",
        "state2"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'CreateICv3'
        QtMocHelpers::SlotData<QDBusPendingReply<int,bool,unsigned int,unsigned int,unsigned int,unsigned int>(const QString &, int)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 }, { QMetaType::Int, 5 },
        }}),
        // Slot 'CreateICv3'
        QtMocHelpers::SlotData<QDBusReply<int>(const QString &, int, bool &, unsigned int &, unsigned int &, unsigned int &, unsigned int &)>(1, 3, QMC::AccessPublic, 0x80000000 | 6, {{
            { QMetaType::QString, 4 }, { QMetaType::Int, 5 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
            { 0x80000000 | 9, 11 }, { 0x80000000 | 9, 12 }, { 0x80000000 | 9, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Fcitx4InputMethodProxy, qt_meta_tag_ZN5fcitx22Fcitx4InputMethodProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject fcitx::Fcitx4InputMethodProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx22Fcitx4InputMethodProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx22Fcitx4InputMethodProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5fcitx22Fcitx4InputMethodProxyE_t>.metaTypes,
    nullptr
} };

void fcitx::Fcitx4InputMethodProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Fcitx4InputMethodProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<int,bool,uint,uint,uint,uint> _r = _t->CreateICv3((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int,bool,uint,uint,uint,uint>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusReply<int> _r = _t->CreateICv3((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QDBusReply<int>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *fcitx::Fcitx4InputMethodProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *fcitx::Fcitx4InputMethodProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5fcitx22Fcitx4InputMethodProxyE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int fcitx::Fcitx4InputMethodProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
